@@ -400,7 +400,7 @@ def LLV(serial,index,period):
     rtn = serial[indx][3]
     for i in range(index-1,index-period-1,-1):
         if rtn < serial[i][3]:
-            rtn = serial[i][3]:
+            rtn = serial[i][3]
     return rtn
 
 class Qualification:
